[Jifty-commit] r2855 - in jifty/trunk: lib/Jifty lib/Jifty/Script

jifty-commit at lists.jifty.org jifty-commit at lists.jifty.org
Tue Feb 27 18:00:25 EST 2007


Author: alexmv
Date: Tue Feb 27 18:00:24 2007
New Revision: 2855

Modified:
   jifty/trunk/   (props changed)
   jifty/trunk/lib/Jifty/Script/Schema.pm
   jifty/trunk/lib/Jifty/Test.pm
   jifty/trunk/lib/Jifty/Util.pm

Log:
 r17439 at zoq-fot-pik:  chmrr | 2007-02-27 18:00:14 -0500
  * Typo nits, on otherwise very nice documentation fixes


Modified: jifty/trunk/lib/Jifty/Script/Schema.pm
==============================================================================
--- jifty/trunk/lib/Jifty/Script/Schema.pm	(original)
+++ jifty/trunk/lib/Jifty/Script/Schema.pm	Tue Feb 27 18:00:24 2007
@@ -500,7 +500,7 @@
 
     # Everything but the template1 database is assumed
     my %connect_args;
-    $connect_args{'database'} = 'template1' if ( $driver eq 'Pg' );
+    $connect_args{'database'} = 'template1' if ( $driver =~ /^Pg/ );
     $connect_args{'database'} = ''          if ( $driver eq 'mysql' );
     $handle->connect(%connect_args);
     return $handle;

Modified: jifty/trunk/lib/Jifty/Test.pm
==============================================================================
--- jifty/trunk/lib/Jifty/Util.pm	(original)
+++ jifty/trunk/lib/Jifty/Util.pm	Tue Feb 27 18:00:24 2007
@@ -125,6 +125,9 @@
 It C<die>s if it can only find C</usr> or C</usr/local> which fit
 these criteria.
 
+If a C<JIFTY_APP_ROOT> environment variable is defined, it searches
+that path first.
+
 =cut
 
 sub app_root {
@@ -135,6 +138,7 @@
     
     my @roots;
 
+    push @roots, $ENV{JIFTY_APP_ROOT} if $ENV{JIFTY_APP_ROOT};
     push( @roots, Cwd::cwd() );
 
     eval { Jifty::Util->require('FindBin') };


More information about the Jifty-commit mailing list
--- jifty/trunk/lib/Jifty/Test.pm	(original)
+++ jifty/trunk/lib/Jifty/Test.pm	Tue Feb 27 18:00:24 2007
@@ -30,7 +30,7 @@
     # Startup an external server (see Jifty::TestServer)
     my $server = Jifty::Test->make_server;
     my $server_url = $server->started_ok;
     # You're probably also interested in Jifty::Test::WWW::Mechanized
 
 =head1 DESCRIPTION
 
@@ -442,7 +442,7 @@
 
 =head1 SEE ALSO
 
-L<Jifty::Test::WWW::Mechanized>, L<Jifty::TestServer>
+L<Jifty::Test::WWW::Mechanize>, L<Jifty::TestServer>
 
 =cut
 
@@ -30,7 +30,7 @@
     my $server = Jifty::Test->make_server;
     my $server_url = $server->started_ok;
-    # You're probably also interested in Jifty::Test::WWW::Mechanized
+    # You're probably also interested in Jifty::Test::WWW::Mechanize
 
 =head1 DESCRIPTION

Modified: jifty/trunk/lib/Jifty/Util.pm
==============================================================================